@@ -13,6 +13,8 @@ from longling.lib.parser import *
 from longling.lib.candylib import *
 from longling.lib.loading import *
 from longling.lib.iterator import *
+from longling.lib.concurrency import *
+from longling.lib.structure.dict import nested_update
 
 from longling.lib import clock
 from longling.lib import regex
@@ -22,4 +24,4 @@ from longling.lib import candylib
 from longling.lib import path
 from longling.lib import parser
 
-__version__ = '1.3.12'
+__version__ = '1.3.13'
